@@ -43,7 +43,7 @@ class TestObject : public QObject
     Q_OBJECT
 public:
     TestObject(KUniqueService *service)
-        : m_proc(Q_NULLPTR), m_callCount(0),
+        : m_proc(nullptr), m_callCount(0),
           m_service(service)
     {}
 
@@ -89,7 +89,7 @@ private Q_SLOTS:
     {
         Q_UNUSED(exitStatus)
         qDebug() << "Process exited with code" << exitCode;
-        m_proc = 0;
+        m_proc = nullptr;
         if (m_callCount == 2) {
             Q_ASSERT(exitCode == 4);
             secondCall();
