@@ -38,6 +38,8 @@
 
 #include "detailscommand.h"
 
+#include "utils/gnupg-helper.h"
+
 #include <dialogs/lookupcertificatesdialog.h>
 
 #include <Libkleo/Formatting>
@@ -107,12 +109,12 @@ private:
     KeyListJob *createKeyListJob(GpgME::Protocol proto) const
     {
         const auto cbp = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
-        return cbp ? cbp->keyListJob(true) : 0;
+        return cbp ? cbp->keyListJob(true) : nullptr;
     }
     ImportFromKeyserverJob *createImportJob(GpgME::Protocol proto) const
     {
         const auto cbp = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
-        return cbp ? cbp->importFromKeyserverJob() : 0;
+        return cbp ? cbp->importFromKeyserverJob() : nullptr;
     }
     void startKeyListJob(GpgME::Protocol proto, const QString &str);
     bool checkConfig() const;
@@ -277,9 +279,9 @@ void LookupCertificatesCommand::Private::slotKeyListResult(const KeyListResult &
 {
 
     if (q->sender() == keyListing.cms) {
-        keyListing.cms = 0;
+        keyListing.cms = nullptr;
     } else if (q->sender() == keyListing.openpgp) {
-        keyListing.openpgp = 0;
+        keyListing.openpgp = nullptr;
     } else {
         qCDebug(KLEOPATRA_LOG) << "unknown sender()" << q->sender();
     }
@@ -313,7 +315,7 @@ void LookupCertificatesCommand::Private::slotKeyListResult(const KeyListResult &
 
 void LookupCertificatesCommand::Private::slotImportRequested(const std::vector<Key> &keys)
 {
-    dialog = 0;
+    dialog = nullptr;
 
     assert(!keys.empty());
     assert(std::none_of(keys.cbegin(), keys.cend(), [](const Key &key) { return key.isNull(); }));
@@ -359,7 +361,7 @@ void LookupCertificatesCommand::doCancel()
 {
     ImportCertificatesCommand::doCancel();
     if (QDialog *const dlg = d->dialog) {
-        d->dialog = 0;
+        d->dialog = nullptr;
         dlg->close();
     }
 }
@@ -391,16 +393,6 @@ void LookupCertificatesCommand::Private::showResult(QWidget *parent, const KeyLi
                                  QStringLiteral("lookup-certificates-truncated-result"));
 }
 
-static bool haveOpenPGPKeyserverConfigured()
-{
-    const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
-    if (!config) {
-        return false;
-    }
-    const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Keyserver"), QStringLiteral("keyserver"));
-    return entry && !entry->stringValue().isEmpty();
-}
-
 static bool haveX509DirectoryServerConfigured()
 {
     const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
@@ -416,7 +408,7 @@ static bool haveX509DirectoryServerConfigured()
 
 bool LookupCertificatesCommand::Private::checkConfig() const
 {
-    const bool ok = haveOpenPGPKeyserverConfigured() || haveX509DirectoryServerConfigured();
+    const bool ok = haveKeyserverConfigured() || haveX509DirectoryServerConfigured();
     if (!ok)
         information(xi18nc("@info",
                            "<para>You do not have any directory servers configured.</para>"
