@@ -49,7 +49,7 @@ class CryptoOperationsConfigWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CryptoOperationsConfigWidget(QWidget *parent = Q_NULLPTR, Qt::WindowFlags f = 0);
+    explicit CryptoOperationsConfigWidget(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
     ~CryptoOperationsConfigWidget();
 
 public Q_SLOTS:
