@@ -71,7 +71,7 @@ class HLine : public QFrame
 {
     Q_OBJECT
 public:
-    explicit HLine(QWidget *p = Q_NULLPTR, Qt::WindowFlags f = 0)
+    explicit HLine(QWidget *p = nullptr, Qt::WindowFlags f = nullptr)
         : QFrame(p, f)
     {
         setFrameStyle(QFrame::HLine | QFrame::Sunken);
@@ -82,7 +82,7 @@ class OperationsWidget : public WizardPage
 {
     Q_OBJECT
 public:
-    explicit OperationsWidget(QWidget *p = Q_NULLPTR);
+    explicit OperationsWidget(QWidget *p = nullptr);
     ~OperationsWidget();
 
     void setOutputDirectory(const QString &dir)
