@@ -47,6 +47,7 @@
 #include <gpg-error.h>
 
 #include "kleopatra_debug.h"
+#include "openpgpcard.h"
 
 #include <QStringList>
 #include <QDir>
@@ -56,10 +57,6 @@
 #include <QThread>
 #include <QPointer>
 
-#include <boost/algorithm/string/split.hpp>
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/algorithm/string/case_conv.hpp>
-
 #include <memory>
 #include <vector>
 #include <set>
@@ -69,39 +66,14 @@
 #include <utility>
 #include <cstdlib>
 
+#include "utils/kdtoolsglobal.h"
+
 using namespace Kleo;
 using namespace Kleo::SmartCard;
 using namespace GpgME;
 
-static const unsigned int CHECK_INTERVAL = 2000; // msecs
+static ReaderStatus *self = nullptr;
 
-static ReaderStatus *self = 0;
-
-struct CardInfo {
-    CardInfo()
-        : fileName(),
-          status(ReaderStatus::NoCard),
-          appType(ReaderStatus::UnknownApplication),
-          appVersion(-1)
-    {
-
-    }
-    CardInfo(const QString &fn, ReaderStatus::Status s)
-        : fileName(fn),
-          status(s),
-          appType(ReaderStatus::UnknownApplication),
-          appVersion(-1)
-    {
-
-    }
-
-    QString fileName;
-    ReaderStatus::Status status;
-    std::string serialNumber;
-    ReaderStatus::AppType appType;
-    int appVersion;
-    std::vector<ReaderStatus::PinState> pinStates;
-};
 
 static const char *flags[] = {
     "NOCARD",
@@ -109,33 +81,20 @@ static const char *flags[] = {
     "ACTIVE",
     "USABLE",
 };
-static_assert(sizeof flags / sizeof * flags == ReaderStatus::_NumScdStates, "");
+static_assert(sizeof flags / sizeof * flags == Card::_NumScdStates, "");
 
 static const char *prettyFlags[] = {
     "NoCard",
     "CardPresent",
     "CardActive",
     "CardUsable",
-    "CardCanLearnKeys",
-    "CardHasNullPin",
     "CardError",
 };
-static_assert(sizeof prettyFlags / sizeof * prettyFlags == ReaderStatus::NumStates, "");
-
-static QByteArray read_file(const QString &fileName)
-{
-    QFile file(fileName);
-    if (!file.exists()) {
-        qCDebug(KLEOPATRA_LOG) << "read_file: file" << fileName << "does not exist";
-        return QByteArray();
-    }
-    if (!file.open(QIODevice::ReadOnly)) {
-        qCDebug(KLEOPATRA_LOG) << "read_file: failed to open" << fileName << ':' << file.errorString();
-        return QByteArray();
-    }
-    return file.readAll().trimmed();
-}
+static_assert(sizeof prettyFlags / sizeof * prettyFlags == Card::NumStates, "");
 
+#if 0
+We need this once we have support for multiple readers in scdaemons
+interface.
 static unsigned int parseFileName(const QString &fileName, bool *ok)
 {
     QRegExp rx(QLatin1String("reader_(\\d+)\\.status"));
@@ -147,23 +106,17 @@ static unsigned int parseFileName(const QString &fileName, bool *ok)
     }
     return 0;
 }
+#endif
+
+Q_DECLARE_METATYPE(GpgME::Error)
 
 namespace
 {
-template <typename T>
-const T &_trace__impl(const T &t, const char *msg)
-{
-    qCDebug(KLEOPATRA_LOG) << msg << t;
-    return t;
-}
-#define TRACE( x ) _trace__impl( x, #x )
-}
-
 static QDebug operator<<(QDebug s, const std::vector< std::pair<std::string, std::string> > &v)
 {
     typedef std::pair<std::string, std::string> pair;
     s << '(';
-    Q_FOREACH (const pair &p, v) {
+    for (const pair &p : v) {
         s << "status(" << QString::fromStdString(p.first) << ") =" << QString::fromStdString(p.second) << endl;
     }
     return s << ')';
@@ -177,9 +130,9 @@ static const char *app_types[] = {
     "dinsig",
     "geldkarte",
 };
-static_assert(sizeof app_types / sizeof * app_types == ReaderStatus::NumAppTypes, "");
+static_assert(sizeof app_types / sizeof * app_types == Card::NumAppTypes, "");
 
-static ReaderStatus::AppType parse_app_type(const std::string &s)
+static Card::AppType parse_app_type(const std::string &s)
 {
     qCDebug(KLEOPATRA_LOG) << "parse_app_type(" << s.c_str() << ")";
     const char **it = std::find_if(std::begin(app_types), std::end(app_types),
@@ -187,9 +140,10 @@ static ReaderStatus::AppType parse_app_type(const std::string &s)
                                     return ::strcasecmp(s.c_str(), type) == 0;
                                 });
     if (it == std::end(app_types)) {
-        return TRACE(ReaderStatus::UnknownApplication);
+        qCDebug(KLEOPATRA_LOG) << "App type not found";
+        return Card::UnknownApplication;
     }
-    return TRACE(static_cast<ReaderStatus::AppType>(it - std::begin(app_types)));
+    return static_cast<Card::AppType>(it - std::begin(app_types));
 
 }
 
@@ -198,32 +152,33 @@ static int parse_app_version(const std::string &s)
     return std::atoi(s.c_str());
 }
 
-static ReaderStatus::PinState parse_pin_state(const std::string &s)
+static Card::PinState parse_pin_state(const QString &s)
 {
-    switch (int i = std::atoi(s.c_str())) {
-    case -4: return ReaderStatus::NullPin;
-    case -3: return ReaderStatus::PinBlocked;
-    case -2: return ReaderStatus::NoPin;
-    case -1: return ReaderStatus::UnknownPinState;
+    bool ok;
+    int i = s.toInt(&ok);
+    if (!ok) {
+        return Card::UnknownPinState;
+    }
+    switch (i) {
+    case -4: return Card::NullPin;
+    case -3: return Card::PinBlocked;
+    case -2: return Card::NoPin;
+    case -1: return Card::UnknownPinState;
     default:
         if (i < 0) {
-            return ReaderStatus::UnknownPinState;
+            return Card::UnknownPinState;
         } else {
-            return ReaderStatus::PinOk;
+            return Card::PinOk;
         }
     }
 }
 
 static std::unique_ptr<DefaultAssuanTransaction> gpgagent_transact(std::shared_ptr<Context> &gpgAgent, const char *command, Error &err)
 {
-#ifdef DEBUG_SCREADER
     qCDebug(KLEOPATRA_LOG) << "gpgagent_transact(" << command << ")";
-#endif
     err = gpgAgent->assuanTransact(command);
     if (err.code()) {
-#ifdef DEBUG_SCREADER
         qCDebug(KLEOPATRA_LOG) << "gpgagent_transact(" << command << "):" << QString::fromLocal8Bit(err.asString());
-#endif
         if (err.code() >= GPG_ERR_ASS_GENERAL && err.code() <= GPG_ERR_ASS_UNKNOWN_INQUIRE) {
             qCDebug(KLEOPATRA_LOG) << "Assuan problem, killing context";
             gpgAgent.reset();
@@ -234,49 +189,42 @@ static std::unique_ptr<DefaultAssuanTransaction> gpgagent_transact(std::shared_p
     return std::unique_ptr<DefaultAssuanTransaction>(dynamic_cast<DefaultAssuanTransaction*>(t.release()));
 }
 
-// returns const std::string so template deduction in boost::split works, and we don't need a temporary
+const std::vector< std::pair<std::string, std::string> > gpgagent_statuslines(std::shared_ptr<Context> gpgAgent, const char *what, Error &err)
+{
+    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, what, err);
+    if (t.get()) {
+        qCDebug(KLEOPATRA_LOG) << "agent_getattr_status(" << what << "): got" << t->statusLines();
+        return t->statusLines();
+    } else {
+        qCDebug(KLEOPATRA_LOG) << "agent_getattr_status(" << what << "): t == NULL";
+        return std::vector<std::pair<std::string, std::string> >();
+    }
+
+}
+
+static const std::string gpgagent_status(std::shared_ptr<Context> gpgAgent, const char *what, Error &err)
+{
+    const auto lines = gpgagent_statuslines (gpgAgent, what, err);
+    // The status is only the last attribute
+    // e.g. for SCD SERIALNO it would only be "SERIALNO" and for SCD GETATTR FOO
+    // it would only be FOO
+    const char *p = strrchr(what, ' ');
+    const char *needle = p + 1 ? p + 1 : what;
+    for (const auto &pair: lines) {
+        if (pair.first == needle) {
+            return pair.second;
+        }
+    }
+    return std::string();
+}
+
 static const std::string scd_getattr_status(std::shared_ptr<Context> &gpgAgent, const char *what, Error &err)
 {
     std::string cmd = "SCD GETATTR ";
     cmd += what;
-    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, cmd.c_str(), err);
-    if (t.get()) {
-        qCDebug(KLEOPATRA_LOG) << "scd_getattr_status(" << what << "): got" << t->statusLines();
-        return t->firstStatusLine(what);
-    } else {
-        qCDebug(KLEOPATRA_LOG) << "scd_getattr_status(" << what << "): t == NULL";
-        return std::string();
-    }
+    return gpgagent_status(gpgAgent, cmd.c_str(), err);
 }
 
-static unsigned int parse_event_counter(const std::string &str)
-{
-    unsigned int result;
-    if (sscanf(str.c_str(), "%*u %*u %u ", &result) == 1) {
-        return result;
-    }
-    return -1;
-}
-
-static unsigned int get_event_counter(std::shared_ptr<Context> &gpgAgent)
-{
-    Error err;
-    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, "GETEVENTCOUNTER", err);
-    if (err.code()) {
-        qCDebug(KLEOPATRA_LOG) << "get_event_counter(): got error" << err.asString();
-    }
-    if (t.get()) {
-#ifdef DEBUG_SCREADER
-        qCDebug(KLEOPATRA_LOG) << "get_event_counter(): got" << t->statusLines();
-#endif
-        return parse_event_counter(t->firstStatusLine("EVENTCOUNTER"));
-    } else {
-        qCDebug(KLEOPATRA_LOG) << "scd_getattr_status(): t == NULL";
-        return -1;
-    }
-}
-
-// returns const std::string so template deduction in boost::split works, and we don't need a temporary
 static const std::string gpgagent_data(std::shared_ptr<Context> &gpgAgent, const char *what, Error &err)
 {
     const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_transact(gpgAgent, what, err);
@@ -311,72 +259,60 @@ static bool parse_keypairinfo_and_lookup_key(Context *ctx, const std::string &kp
     return !e && !key.isNull();
 }
 
-static CardInfo get_card_status(const QString &fileName, unsigned int idx, std::shared_ptr<Context> &gpg_agent)
+static void handle_openpgp_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context> &gpg_agent)
 {
-#ifdef DEBUG_SCREADER
-    qCDebug(KLEOPATRA_LOG) << "get_card_status(" << fileName << ',' << idx << ',' << gpg_agent.get() << ')';
-#endif
-    CardInfo ci(fileName, ReaderStatus::CardUsable);
-    if (idx != 0 || !gpg_agent) {
-        return ci;
-    }
     Error err;
-    ci.serialNumber = gpgagent_data(gpg_agent, "SCD SERIALNO", err);
-    if (err.code() == GPG_ERR_CARD_NOT_PRESENT || err.code() == GPG_ERR_CARD_REMOVED) {
-        ci.status = ReaderStatus::NoCard;
-        return ci;
-    }
-    if (err.code()) {
-        ci.status = ReaderStatus::CardError;
-        return ci;
-    }
-    ci.appType = parse_app_type(scd_getattr_status(gpg_agent, "APPTYPE", err));
-    if (err.code()) {
-        return ci;
-    }
-    if (ci.appType != ReaderStatus::NksApplication) {
-        qCDebug(KLEOPATRA_LOG) << "get_card_status: not a NetKey card, giving up";
-        return ci;
-    }
-    ci.appVersion = parse_app_version(scd_getattr_status(gpg_agent, "NKS-VERSION", err));
-    if (err.code()) {
-        return ci;
-    }
-    if (ci.appVersion != 3) {
-        qCDebug(KLEOPATRA_LOG) << "get_card_status: not a NetKey v3 card, giving up";
-        return ci;
-    }
+    auto ret = new OpenPGPCard();
+    ret->setSerialNumber(ci->serialNumber());
 
+    const auto info = gpgagent_statuslines(gpg_agent, "SCD LEARN --keypairinfo", err);
+    if (err.code()) {
+        ci->setStatus(Card::CardError);
+        return;
+    }
+    ret->setKeyPairInfo(info);
+    ci.reset(ret);
+}
+
+static void handle_netkey_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context> &gpg_agent)
+{
+    Error err;
+    ci->setAppVersion(parse_app_version(scd_getattr_status(gpg_agent, "NKS-VERSION", err)));
+    if (err.code() || ci->appVersion() != 3) {
+        qCDebug(KLEOPATRA_LOG) << "not a NetKey v3 card, giving up";
+        return;
+    }
     // the following only works for NKS v3...
-    std::vector<std::string> chvStatus;
-    chvStatus.reserve(4);   // expected number of fields
-    boost::split(chvStatus, scd_getattr_status(gpg_agent, "CHV-STATUS", err), boost::is_any_of(" \t"), boost::token_compress_on);
+    const auto chvStatus = QString::fromStdString(
+            scd_getattr_status(gpg_agent, "CHV-STATUS", err)).split(QStringLiteral(" \t"));
     if (err.code()) {
-        return ci;
+        return;
     }
-    std::transform(chvStatus.begin(), chvStatus.end(),
-                   std::back_inserter(ci.pinStates),
-                   parse_pin_state);
 
-    if (std::find(ci.pinStates.cbegin(), ci.pinStates.cend(), ReaderStatus::NullPin) != ci.pinStates.cend()) {
-        ci.status = ReaderStatus::CardHasNullPin;
-        return ci;
+    std::vector<Card::PinState> states;
+    for (const auto &state: chvStatus) {
+        const auto parsed = parse_pin_state (state);
+        states.push_back(parsed);
+        if (parsed == Card::NullPin) {
+            ci->setHasNullPin(true);
+        }
     }
+    ci->setPinStates(states);
 
     // check for keys to learn:
     const std::unique_ptr<DefaultAssuanTransaction> result = gpgagent_transact(gpg_agent, "SCD LEARN --keypairinfo", err);
     if (err.code() || !result.get()) {
-        return ci;
+        return;
     }
     const std::vector<std::string> keyPairInfos = result->statusLine("KEYPAIRINFO");
     if (keyPairInfos.empty()) {
-        return ci;
+        return;
     }
 
-    // check that any of the
-    const std::unique_ptr<Context> klc(Context::createForProtocol(CMS));     // what about OpenPGP?
+    // check that any of the keys are new
+    const std::unique_ptr<Context> klc(Context::createForProtocol(CMS));
     if (!klc.get()) {
-        return ci;
+        return;
     }
     klc->setKeyListMode(Ephemeral);
 
@@ -384,57 +320,76 @@ static CardInfo get_card_status(const QString &fileName, unsigned int idx, std::
                     [&klc](const std::string &str) {
                         return !parse_keypairinfo_and_lookup_key(klc.get(), str);
                     })) {
-        ci.status = ReaderStatus::CardCanLearnKeys;
+        ci->setCanLearnKeys(true);
+    }
+    return;
+}
+
+static std::shared_ptr<Card> get_card_status(unsigned int slot, std::shared_ptr<Context> &gpg_agent)
+{
+    Q_UNUSED(gpgagent_data);
+    qCDebug(KLEOPATRA_LOG) << "get_card_status(" << slot << ',' << gpg_agent.get() << ')';
+    auto ci = std::shared_ptr<Card> (new Card());
+    if (slot != 0 || !gpg_agent) {
+        // In the future scdaemon should support multiple slots but
+        // not yet (2.1.18)
+        return ci;
     }
 
-#ifdef DEBUG_SCREADER
-    qCDebug(KLEOPATRA_LOG) << "get_card_status: ci.status " << prettyFlags[ci.status];
-#endif
+    Error err;
+    ci->setSerialNumber(gpgagent_status(gpg_agent, "SCD SERIALNO", err));
+    if (err.code() == GPG_ERR_CARD_NOT_PRESENT || err.code() == GPG_ERR_CARD_REMOVED) {
+        ci->setStatus(Card::NoCard);
+        return ci;
+    }
+    if (err.code()) {
+        ci->setStatus(Card::CardError);
+        return ci;
+    }
+    ci->setStatus(Card::CardPresent);
+
+    const auto verbatimType = scd_getattr_status(gpg_agent, "APPTYPE", err);
+    ci->setAppType(parse_app_type(verbatimType));
+    if (err.code()) {
+        return ci;
+    }
+
+    // Handle different card types
+    if (ci->appType() == Card::NksApplication) {
+        qCDebug(KLEOPATRA_LOG) << "get_card_status: found Netkey card" << ci->serialNumber().c_str() << "end";
+        handle_netkey_card(ci, gpg_agent);
+        return ci;
+    } else if (ci->appType() == Card::OpenPGPApplication) {
+        qCDebug(KLEOPATRA_LOG) << "get_card_status: found OpenPGP card" << ci->serialNumber().c_str() << "end";
+        handle_openpgp_card(ci, gpg_agent);
+        return ci;
+    } else {
+        qCDebug(KLEOPATRA_LOG) << "get_card_status: unhandled application:" << verbatimType.c_str();
+        return ci;
+    }
 
     return ci;
 }
 
-static std::vector<CardInfo> update_cardinfo(const QString &gnupgHomePath, std::shared_ptr<Context> &gpgAgent)
+static std::vector<std::shared_ptr<Card> > update_cardinfo(std::shared_ptr<Context> &gpgAgent)
 {
-#ifdef DEBUG_SCREADER
-    qCDebug(KLEOPATRA_LOG) << "<update_cardinfo>";
-#endif
-    const QDir gnupgHome(gnupgHomePath);
-    if (!gnupgHome.exists()) {
-        qCWarning(KLEOPATRA_LOG) << "gnupg home" << gnupgHomePath << "does not exist!";
-    }
-
-    const CardInfo ci = get_card_status(gnupgHome.absoluteFilePath(QStringLiteral("reader_0.status")), 0, gpgAgent);
-#ifdef DEBUG_SCREADER
-    qCDebug(KLEOPATRA_LOG) << "</update_cardinfo>";
-#endif
-    return std::vector<CardInfo>(1, ci);
-}
-
-static bool check_event_counter_changed(std::shared_ptr<Context> &gpg_agent, unsigned int &counter)
-{
-    const unsigned int oldCounter = counter;
-    counter = get_event_counter(gpg_agent);
-    if (oldCounter != counter) {
-#ifdef DEBUG_SCREADER
-        qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: events:" << oldCounter << "->" << counter;
-#endif
-        return true;
-    } else {
-        return false;
-    }
+    // Multiple smartcard readers are only supported internally by gnupg
+    // but not by scdaemon (Status gnupg 2.1.18)
+    // We still pretend that there can be multiple cards inserted
+    // at once but we don't handle it yet.
+    const auto ci = get_card_status(0, gpgAgent);
+    return std::vector<std::shared_ptr<Card> >(1, ci);
 }
+} // namespace
 
 struct Transaction {
     QByteArray command;
     QPointer<QObject> receiver;
     const char *slot;
-    GpgME::Error error;
 };
 
-static const Transaction checkTransaction  = { "__check__",  0, 0, Error() };
-static const Transaction updateTransaction = { "__update__", 0, 0, Error() };
-static const Transaction quitTransaction   = { "__quit__",   0, 0, Error() };
+static const Transaction updateTransaction = { "__update__", nullptr, nullptr };
+static const Transaction quitTransaction   = { "__quit__",   nullptr, nullptr };
 
 namespace
 {
@@ -442,7 +397,7 @@ class ReaderStatusThread : public QThread
 {
     Q_OBJECT
 public:
-    explicit ReaderStatusThread(QObject *parent = Q_NULLPTR)
+    explicit ReaderStatusThread(QObject *parent = nullptr)
         : QThread(parent),
           m_gnupgHomePath(Kleo::gnupgHomeDirectory()),
           m_transactions(1, updateTransaction)   // force initial scan
@@ -451,19 +406,19 @@ public:
                 this, &ReaderStatusThread::slotOneTransactionFinished);
     }
 
-    std::vector<CardInfo> cardInfos() const
+    std::vector<std::shared_ptr<Card> > cardInfos() const
     {
         const QMutexLocker locker(&m_mutex);
         return m_cardInfos;
     }
 
-    ReaderStatus::Status cardStatus(unsigned int slot) const
+    Card::Status cardStatus(unsigned int slot) const
     {
         const QMutexLocker locker(&m_mutex);
         if (slot < m_cardInfos.size()) {
-            return m_cardInfos[slot].status;
+            return m_cardInfos[slot]->status();
         } else {
-            return ReaderStatus::NoCard;
+            return Card::NoCard;
         }
     }
 
@@ -474,14 +429,11 @@ public:
         m_waitForTransactions.wakeOne();
     }
 
-    // make QThread::sleep public
-    using QThread::sleep;
-
 Q_SIGNALS:
     void anyCardHasNullPinChanged(bool);
     void anyCardCanLearnKeysChanged(bool);
-    void cardStatusChanged(unsigned int, Kleo::SmartCard::ReaderStatus::Status);
-    void oneTransactionFinished();
+    void cardChanged(unsigned int);
+    void oneTransactionFinished(GpgME::Error err);
 
 public Q_SLOTS:
     void ping()
@@ -497,94 +449,41 @@ public Q_SLOTS:
         m_waitForTransactions.wakeOne();
     }
 
-    void slotReaderStatusFileChanged()
-    {
-        const QDir gnupgHome(m_gnupgHomePath);
-        if (!gnupgHome.exists()) {
-            qCWarning(KLEOPATRA_LOG) << "gnupg home" << m_gnupgHomePath << "does not exist!";
-            return;
-        }
-
-        QStringList files = gnupgHome.entryList(QStringList(QStringLiteral("reader_*.status")), QDir::Files, QDir::Name);
-        std::sort(files.begin(), files.end(),
-                  [](const QString &lhs, const QString &rhs) {
-                      return parseFileName(lhs, Q_NULLPTR) < parseFileName(rhs, Q_NULLPTR);
-                  });
-
-        std::vector<QByteArray> contents;
-
-        Q_FOREACH (const QString &file, files) {
-            bool ok = false;
-            const unsigned int idx = parseFileName(file, &ok);
-            if (!ok) {
-                qCDebug(KLEOPATRA_LOG) << "filename" << file << ": cannot parse reader slot number";
-                continue;
-            }
-            assert(idx >= contents.size());
-            contents.resize(idx);
-            contents.push_back(read_file(gnupgHome.absoluteFilePath(file)));
-        }
-
-        // canonicalise by removing empty stuff from the end
-        while (!contents.empty() && contents.back().isEmpty()) {
-            contents.pop_back();
-        }
-
-        if (contents != readerStatusFileContents) {
-            ping();
-        }
-
-        readerStatusFileContents.swap(contents);
-    }
-
 private Q_SLOTS:
-    void slotOneTransactionFinished()
+    void slotOneTransactionFinished(GpgME::Error err)
     {
         std::list<Transaction> ft;
         KDAB_SYNCHRONIZED(m_mutex)
         ft.splice(ft.begin(), m_finishedTransactions);
         Q_FOREACH (const Transaction &t, ft)
             if (t.receiver && t.slot && *t.slot) {
-                QMetaObject::invokeMethod(t.receiver, t.slot, Qt::DirectConnection, Q_ARG(GpgME::Error, t.error));
+                QMetaObject::invokeMethod(t.receiver, t.slot, Qt::DirectConnection, Q_ARG(GpgME::Error, err));
             }
     }
 
 private:
     void run() Q_DECL_OVERRIDE {
-
-        std::shared_ptr<Context> gpgAgent;
-        unsigned int eventCounter = -1;
-
-        while (true)
-        {
+        while (true) {
+            std::shared_ptr<Context> gpgAgent;
 
             QByteArray command;
-            bool nullSlot;
+            bool nullSlot = false;
             std::list<Transaction> item;
-            std::vector<CardInfo> oldCardInfos;
+            std::vector<std::shared_ptr<Card> > oldCards;
 
-            if (!gpgAgent) {
-                Error err;
-                std::unique_ptr<Context> c = Context::createForEngine(AssuanEngine, &err);
-                if (err.code() == GPG_ERR_NOT_SUPPORTED) {
-                    return;
-                }
-                gpgAgent = std::shared_ptr<Context>(c.release());
+            Error err;
+            std::unique_ptr<Context> c = Context::createForEngine(AssuanEngine, &err);
+            if (err.code() == GPG_ERR_NOT_SUPPORTED) {
+                return;
             }
+            gpgAgent = std::shared_ptr<Context>(c.release());
 
             KDAB_SYNCHRONIZED(m_mutex) {
 
                 while (m_transactions.empty()) {
                     // go to sleep waiting for more work:
-#ifdef DEBUG_SCREADER
-                    qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: .zZZ";
-#endif
-                    if (!m_waitForTransactions.wait(&m_mutex, CHECK_INTERVAL)) {
-                        m_transactions.push_front(checkTransaction);
-                    }
-#ifdef DEBUG_SCREADER
-                    qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: .oOO";
-#endif
+                    qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: waiting for commands";
+                    m_waitForTransactions.wait(&m_mutex);
                 }
 
                 // splice off the first transaction without
@@ -598,56 +497,47 @@ private:
                 // we can release the mutex again:
                 command = item.front().command;
                 nullSlot = !item.front().slot;
-                oldCardInfos = m_cardInfos;
+                oldCards = m_cardInfos;
             }
 
-#ifdef DEBUG_SCREADER
             qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: new iteration command=" << command << " ; nullSlot=" << nullSlot;
-#endif
             // now, let's see what we got:
-
             if (nullSlot && command == quitTransaction.command) {
                 return;    // quit
             }
 
-            if ((nullSlot && command == updateTransaction.command) ||
-                    (nullSlot && command == checkTransaction.command)) {
+            if ((nullSlot && command == updateTransaction.command)) {
 
-                if (nullSlot && command == checkTransaction.command && !check_event_counter_changed(gpgAgent, eventCounter)) {
-                    continue;    // early out
-                }
+                std::vector<std::shared_ptr<Card> > newCards = update_cardinfo(gpgAgent);
 
-                std::vector<CardInfo> newCardInfos
-                    = update_cardinfo(m_gnupgHomePath, gpgAgent);
-
-                newCardInfos.resize(std::max(newCardInfos.size(), oldCardInfos.size()));
-                oldCardInfos.resize(std::max(newCardInfos.size(), oldCardInfos.size()));
+                newCards.resize(std::max(newCards.size(), oldCards.size()));
+                oldCards.resize(std::max(newCards.size(), oldCards.size()));
 
                 KDAB_SYNCHRONIZED(m_mutex)
-                m_cardInfos = newCardInfos;
+                m_cardInfos = newCards;
 
-                std::vector<CardInfo>::const_iterator
-                nit = newCardInfos.begin(), nend = newCardInfos.end(),
-                oit = oldCardInfos.begin(), oend = oldCardInfos.end();
+                std::vector<std::shared_ptr<Card> >::const_iterator
+                nit = newCards.begin(), nend = newCards.end(),
+                oit = oldCards.begin(), oend = oldCards.end();
 
                 unsigned int idx = 0;
                 bool anyLC = false;
                 bool anyNP = false;
                 bool anyError = false;
                 while (nit != nend && oit != oend) {
-                    if (nit->status != oit->status) {
-#ifdef DEBUG_SCREADER
-                        qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: slot" << idx << ":" << prettyFlags[oit->status] << "->" << prettyFlags[nit->status];
-#endif
-                        Q_EMIT cardStatusChanged(idx, nit->status);
+                    const auto optr = (*oit).get();
+                    const auto nptr = (*nit).get();
+                    if ((optr && !nptr) || (!optr && nptr) || (optr && nptr && *optr != *nptr)) {
+                        qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[2nd]: slot" << idx << ": card Changed";
+                        Q_EMIT cardChanged(idx);
                     }
-                    if (nit->status == ReaderStatus::CardCanLearnKeys) {
+                    if ((*nit)->canLearnKeys()) {
                         anyLC = true;
                     }
-                    if (nit->status == ReaderStatus::CardHasNullPin) {
+                    if ((*nit)->hasNullPin()) {
                         anyNP = true;
                     }
-                    if (nit->status == ReaderStatus::CardError) {
+                    if ((*nit)->status() == Card::CardError) {
                         anyError = true;
                     }
                     ++nit;
@@ -661,30 +551,16 @@ private:
                 if (anyError) {
                     gpgAgent.reset();
                 }
-
             } else {
-
-                (void)gpgagent_transact(gpgAgent, command.constData(), item.front().error);
+                GpgME::Error err;
+                (void)gpgagent_transact(gpgAgent, command.constData(), err);
 
                 KDAB_SYNCHRONIZED(m_mutex)
                 // splice 'item' into m_finishedTransactions:
                 m_finishedTransactions.splice(m_finishedTransactions.end(), item);
 
-                Q_EMIT oneTransactionFinished();
-
+                Q_EMIT oneTransactionFinished(err);
             }
-
-            // update event counter in case anything above changed
-            // it:
-            if (gpgAgent) {
-                eventCounter = get_event_counter(gpgAgent);
-            } else {
-                eventCounter = -1;
-            }
-#ifdef DEBUG_SCREADER
-            qCDebug(KLEOPATRA_LOG) << "eventCounter:" << eventCounter;
-#endif
-
         }
     }
 
@@ -692,9 +568,8 @@ private:
     mutable QMutex m_mutex;
     QWaitCondition m_waitForTransactions;
     const QString m_gnupgHomePath;
-    std::vector<QByteArray> readerStatusFileContents;
     // protected by m_mutex:
-    std::vector<CardInfo> m_cardInfos;
+    std::vector<std::shared_ptr<Card> > m_cardInfos;
     std::list<Transaction> m_transactions, m_finishedTransactions;
 };
 
@@ -712,20 +587,21 @@ public:
     {
         KDAB_SET_OBJECT_NAME(watcher);
 
-        qRegisterMetaType<Status>("Kleo::SmartCard::ReaderStatus::Status");
+        qRegisterMetaType<Card::Status>("Kleo::SmartCard::Card::Status");
+        qRegisterMetaType<GpgME::Error>("GpgME::Error");
 
         watcher.whitelistFiles(QStringList(QStringLiteral("reader_*.status")));
         watcher.addPath(Kleo::gnupgHomeDirectory());
         watcher.setDelay(100);
 
-        connect(this, &::ReaderStatusThread::cardStatusChanged,
-                q, &ReaderStatus::cardStatusChanged);
+        connect(this, &::ReaderStatusThread::cardChanged,
+                q, &ReaderStatus::cardChanged);
         connect(this, &::ReaderStatusThread::anyCardHasNullPinChanged,
                 q, &ReaderStatus::anyCardHasNullPinChanged);
         connect(this, &::ReaderStatusThread::anyCardCanLearnKeysChanged,
                 q, &ReaderStatus::anyCardCanLearnKeysChanged);
 
-        connect(&watcher, &FileSystemWatcher::triggered, this, &::ReaderStatusThread::slotReaderStatusFileChanged);
+        connect(&watcher, &FileSystemWatcher::triggered, this, &::ReaderStatusThread::ping);
 
     }
     ~Private()
@@ -742,14 +618,14 @@ private:
     {
         const auto cis = cardInfos();
         return std::any_of(cis.cbegin(), cis.cend(),
-                           [](const CardInfo &ci) { return ci.status == CardHasNullPin; });
+                           [](const std::shared_ptr<Card> &ci) { return ci->hasNullPin(); });
     }
 
     bool anyCardCanLearnKeysImpl() const
     {
         const auto cis = cardInfos();
         return std::any_of(cis.cbegin(), cis.cend(),
-                           [](const CardInfo &ci) { return ci.status == CardCanLearnKeys; });
+                           [](const std::shared_ptr<Card> &ci) { return ci->canLearnKeys(); });
     }
 
 private:
@@ -764,7 +640,7 @@ ReaderStatus::ReaderStatus(QObject *parent)
 
 ReaderStatus::~ReaderStatus()
 {
-    self = 0;
+    self = nullptr;
 }
 
 // slot
@@ -785,7 +661,7 @@ const ReaderStatus *ReaderStatus::instance()
     return self;
 }
 
-ReaderStatus::Status ReaderStatus::cardStatus(unsigned int slot) const
+Card::Status ReaderStatus::cardStatus(unsigned int slot) const
 {
     return d->cardStatus(slot);
 }
@@ -800,19 +676,19 @@ bool ReaderStatus::anyCardCanLearnKeys() const
     return d->anyCardCanLearnKeysImpl();
 }
 
-std::vector<ReaderStatus::PinState> ReaderStatus::pinStates(unsigned int slot) const
+std::vector<Card::PinState> ReaderStatus::pinStates(unsigned int slot) const
 {
-    const std::vector<CardInfo> ci = d->cardInfos();
+    const auto ci = d->cardInfos();
     if (slot < ci.size()) {
-        return ci[slot].pinStates;
+        return ci[slot]->pinStates();
     } else {
-        return std::vector<PinState>();
+        return std::vector<Card::PinState>();
     }
 }
 
 void ReaderStatus::startSimpleTransaction(const QByteArray &command, QObject *receiver, const char *slot)
 {
-    const Transaction t = { command, receiver, slot, Error() };
+    const Transaction t = { command, receiver, slot };
     d->addTransaction(t);
 }
 
@@ -821,4 +697,9 @@ void ReaderStatus::updateStatus()
     d->ping();
 }
 
+std::vector <std::shared_ptr<Card> > ReaderStatus::getCards() const
+{
+    return d->cardInfos();
+}
+
 #include "readerstatus.moc"
