@@ -33,10 +33,12 @@
 #include <config-kleopatra.h>
 
 #include "decryptverifycommandfilesbase.h"
+#include "fileoperationspreferences.h"
 
 #include <crypto/decryptverifytask.h>
 
-#include <crypto/decryptverifyfilescontroller.h>
+#include "crypto/decryptverifyfilescontroller.h"
+#include "crypto/autodecryptverifyfilescontroller.h"
 
 #include <utils/hex.h>
 #include <utils/input.h>
@@ -117,7 +119,12 @@ int DecryptVerifyCommandFilesBase::doStart()
 
     d->checkForErrors();
 
-    d->controller.reset(new DecryptVerifyFilesController(shared_from_this()));
+    FileOperationsPreferences prefs;
+    if (prefs.autoDecryptVerify()) {
+        d->controller.reset(new AutoDecryptVerifyFilesController());
+    } else {
+        d->controller.reset(new DecryptVerifyFilesController(shared_from_this()));
+    }
 
     d->controller->setOperation(operation());
     d->controller->setFiles(fileNames());
@@ -199,7 +206,7 @@ void DecryptVerifyCommandFilesBase::Private::verificationResult(const Verificati
     try {
         const std::vector<Signature> sigs = vResult.signatures();
         const std::vector<Key> signers = KeyCache::instance()->findSigners(vResult);
-        Q_FOREACH (const Signature &sig, sigs) {
+        for (const Signature &sig : sigs) {
             const QString s = signatureToString(sig, DecryptVerifyResult::keyForSignature(sig, signers));
             const char *color = summaryToString(sig.summary());
             q->sendStatusEncoded("SIGSTATUS",
