@@ -148,7 +148,7 @@ struct inhibit_close : T_IODevice {
     template <typename T1>
     explicit inhibit_close(T1 &t1) : T_IODevice(t1) {}
 
-    /* reimp */ void close() {}
+    /* reimp */ void close() Q_DECL_OVERRIDE {}
     void reallyClose()
     {
         T_IODevice::close();
@@ -161,7 +161,7 @@ struct redirect_close : T_IODevice {
     template <typename T1>
     explicit redirect_close(T1 &t1) : T_IODevice(t1), m_closed(false) {}
 
-    /* reimp */ void close()
+    /* reimp */ void close() Q_DECL_OVERRIDE
     {
         this->closeWriteChannel();
         m_closed = true;
@@ -422,7 +422,7 @@ PipeOutput::PipeOutput(assuan_fd_t fd)
 
 std::shared_ptr<Output> Output::createFromFile(const QString &fileName, bool forceOverwrite)
 {
-    return createFromFile(fileName, std::shared_ptr<OverwritePolicy>(new OverwritePolicy(0, forceOverwrite ? OverwritePolicy::Allow : OverwritePolicy::Deny)));
+    return createFromFile(fileName, std::shared_ptr<OverwritePolicy>(new OverwritePolicy(nullptr, forceOverwrite ? OverwritePolicy::Allow : OverwritePolicy::Deny)));
 
 }
 std::shared_ptr<Output> Output::createFromFile(const QString &fileName, const std::shared_ptr<OverwritePolicy> &policy)
@@ -561,7 +561,7 @@ QString ProcessStdInOutput::label() const
         return OutputImplBase::label();
     }
     // output max. 3 arguments
-    const QString cmdline = (QStringList(m_command) + m_arguments.mid(0, 3)).join(QStringLiteral(" "));
+    const QString cmdline = (QStringList(m_command) + m_arguments.mid(0, 3)).join(QLatin1Char(' '));
     if (m_arguments.size() > 3) {
         return i18nc("e.g. \"Input to tar xf - file1 ...\"", "Input to %1 ...", cmdline);
     } else {
